searchNodes=[{"doc":"Permutation defines a protocol for calculating all possible permutations of a given type of data. The protocol may be implemented for any type of custom data which requires the calcuation of permutations (or combintations). Examples MapSet s are used when members have no inherent order: iex&gt; mapset = MapSet . new ( [ :paris , :rome , :tokyo , :budapest ] ) # MapSet &lt; [ :budapest , :paris , :rome , :tokyo ] &gt; iex&gt; Permutation . permute ( mapset ) { :ok , # MapSet &lt; [ # MapSet &lt; [ :budapest , :paris , :rome , :tokyo ] &gt; ] &gt; } List s are used when the members ARE ordered: iex&gt; Permutation . permute ( [ :a , :b , :c ] ) { :ok , # MapSet &lt; [ [ :a , :b , :c ] , [ :a , :c , :b ] , [ :b , :a , :c ] , [ :b , :c , :a ] , [ :c , :a , :b ] , [ :c , :b , :a ] ] &gt; }","ref":"Permutation.html","title":"Permutation","type":"protocol"},{"doc":"Find all possible combinations of the collection 's members, returned as a MapSet . Options :cardinality the maximum size of the resulting subsets","ref":"Permutation.html#permute/2","title":"Permutation.permute/2","type":"function"},{"doc":"As with Permutation.permute/2 but raises on error.","ref":"Permutation.html#permute!/2","title":"Permutation.permute!/2","type":"function"},{"doc":"","ref":"Permutation.html#t:t/0","title":"Permutation.t/0","type":"type"},{"doc":"This is an Elixir package that calculates permutations of enumerables, including combinations , where the order does not matter. This is implemented as an Elixir Protocol, which helps communiate the difference between permutations and combinations in way that is more familiar to Elixir programmers: the permutations of List s are true permutations, whereas the &quot;permutations&quot; of MapSet s are combinations (because MapSet s have no inherent order).","ref":"readme.html","title":"Permutation","type":"extras"},{"doc":"The output of Permutation.permute/2 is always a MapSet , regardless of the type of data that is evaluated. This is because the possible permutations are not inherently ordered. The members of the outputted MapSet are of the same data type as the input. E.g. the permutation result of a List yields a MapSet of List s. The permutation result of a MapSet yields a MapSet of MapSet s. The :cardinality option can be specified where only a subset of the original items should be returned. When a MapSet is permuted, the results are &quot;combinations&quot; where the order of the items is not considered: iex&gt; mapset = MapSet . new ( [ :paris , :rome , :tokyo , :budapest ] ) # MapSet &lt; [ :budapest , :paris , :rome , :tokyo ] &gt; iex&gt; Permutation . permute ( mapset , cardinality : 2 ) { :ok , # MapSet &lt; [ # MapSet &lt; [ :budapest , :paris ] &gt; , # MapSet &lt; [ :budapest , :rome ] &gt; , # MapSet &lt; [ :budapest , :tokyo ] &gt; , # MapSet &lt; [ :paris , :rome ] &gt; , # MapSet &lt; [ :paris , :tokyo ] &gt; , # MapSet &lt; [ :rome , :tokyo ] &gt; ] &gt; } When a List is permuted, this yields true permutations where the order of the items is considered (so there are therefore, more possibilities): iex&gt; list = [ :paris , :rome , :tokyo , :budapest ] iex&gt; Permutation . permute ( list , cardinality : 2 ) { :ok , # MapSet &lt; [ [ :budapest , :paris ] , [ :budapest , :rome ] , [ :budapest , :tokyo ] , [ :paris , :budapest ] , [ :paris , :rome ] , [ :paris , :tokyo ] , [ :rome , :budapest ] , [ :rome , :paris ] , [ :rome , :tokyo ] , [ :tokyo , :budapest ] , [ :tokyo , :paris ] , [ :tokyo , :rome ] ] &gt; }","ref":"readme.html#examples","title":"Permutation - Examples","type":"extras"},{"doc":"This package can be installed by adding permutation to your list of dependencies in mix.exs : def deps do [ { :permutation , &quot;~&gt; 0.1.0&quot; } ] end","ref":"readme.html#installation","title":"Permutation - Installation","type":"extras"},{"doc":"This package would have taken me much longer to write if it weren't for the hard work and helpful explanations of those who went before: http://www.petecorey.com/blog/2018/11/12/permutations-with-and-without-repetition-in-elixir/ https://github.com/seantanly/elixir-combination https://github.com/pcorey/chord/blob/master/lib/permutation.ex","ref":"readme.html#see-also","title":"Permutation - See Also","type":"extras"},{"doc":"The format is based on Keep a Changelog , and this project adheres to Semantic Versioning .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Initial release with all the needed functionality present.","ref":"changelog.html#v0-1-0","title":"Changelog - v0.1.0","type":"extras"}]